if (typeof define !== 'function') {
  var define = require('amdefine')(module);
}
define(['require', './../src/webfinger.js'], function (require, amdwf) {
  var tests = [
    {
      desc: 'ensure amd module is loaded correctly',
      run: function (env, test) {
        test.assertType(amdwf, 'function');
      }
    },
    {
      desc: 'ensure amd module can be used to create a wf object',
      run: function (env, test) {
        var wf = new amdwf();
        test.assertTypeAnd(wf, 'object');
        test.assertType(wf.lookup, 'function');
      }
    },

    {
      desc: 'calling function with no params fails',
      run: function (env, test) {
        test.throws(env.wf.lookup, Error, 'caught thrown exception');
      }
    },

    {
      desc: 'calling with invalid useraddress',
      run: function (env, test) {
        test.throws(function () { env.wf.lookup('asdfg'); }, Error, 'caught thrown exception');
      }
    },

    {
      desc: 'allow for port localhost without ssl',
      run: function (env, test) {
        env.wf.lookup('me@localhost:8001', function (err, data) {
          if (err) {
            test.assertAnd(err.url.indexOf('http://'), 0);
            test.assert(err.message, 'error during request');
          } else {
            test.done();
          }
        });
      }
    },

    {
      desc: 'calling with incorrect useraddress',
      run: function (env, test) {
        env.wf.lookup('bobby@gmail.com', function (err, data) {
          test.assertTypeAnd(err, 'object');
          test.assert(err.status, 404);
        });
      }
    },

    {
      desc: 'calling with incorrect useraddress (fallbacks enabled) v1',
      run: function (env, test) {
        var rswf = new env.WebFinger({
          tls_only: false,
          uri_fallback: true,
          request_timeout: 5000
        });

        rswf.lookup('bobby@gmail.com', function (err, data) {
          test.assertType(err, 'object');
          // test.assert(err.status, 404);
        });
      }
    },

    {
      desc: 'calling with incorrect useraddress (fallbacks enabled) v2',
      run: function (env, test) {
        var rswf = new env.WebFinger({
          tls_only: false,
          uri_fallback: true,
          request_timeout: 5000
        });

        rswf.lookup('foo@bar', function (err, data) {
          test.assertType(err, 'object');
          test.assert(err.status, 404);
        });
      }
    },

    {
      desc: 'process a well-formed JRD document',
      run: function (env, test) {
        env.wf.__processJRD('some:url', JSON.stringify({ links: [] }), function (err) {
          test.fail(err);
        }, function(res) {
          test.done();
        });
      }
    },

    {
      desc: 'process a malformed JRD document',
      run: function (env, test) {
        env.wf.__processJRD('some:url', JSON.stringify({ links: {} }), function (err) {
          test.fail(err);
        }, function(res) {
          test.done();
        });
      }
    }
  ];


  var suites = [];

  var setup = function (env, test) {
    env.WebFinger = require('./../src/webfinger.js');
    env.wf = new env.WebFinger({request_timeout: 3000});
    test.assertTypeAnd(env.wf, 'object');
    test.assertType(env.wf.lookup, 'function');
  };

  var setup_XHR = function (env, test) {
    setup(env, test);
    XMLHttpRequest = require('xhr2');
  };

  suites.push({
    desc: "basic webfinger.js tests using XHR",
    abortOnFail: true,
    setup: setup_XHR,
    tests: tests
  });

  var setup_fetch = function (env, test) {
    setup(env, test);
    fetch = require('node-fetch');
  };

  suites.push({
    desc: "basic webfinger.js tests using fetch",
    abortOnFail: true,
    setup: setup_fetch,
    tests: tests
  });

  return suites;
});
